# git root
DRWATERGITROOT <- "drwater.rcees.ac.cn/git/"
DRWATERPKGS <- c(
  "dwfun", "langeR", "rmdify", "dateR",
  "dfeR", "limvis", "uniteR", "cctda", "cctdb",
  "mapeR", "meteR", "drwateR", "uniteR"
)
# Define core packages
CORE <- c("dwfun", "langeR", "rmdify", "dateR", "dfeR", "uniteR")

# Function to check which core packages are not loaded
core_unloaded <- function(core = CORE) {
  loaded <- paste0("package:", core) %in% search()
  core[!loaded]
}

# Attach the package from the same package library it was loaded from before
same_library <- function(pkg) {
  if (!requireNamespace(pkg, quietly = TRUE)) {
    message(pkg, " has not been installed!")
    return(invisible(NULL))
  }
  loc <- if (pkg %in% loadedNamespaces()) {
    dirname(getNamespaceInfo(pkg, "path"))
  } else {
    NULL
  }
  library(pkg,
    lib.loc = loc, character.only = TRUE,
    warn.conflicts = FALSE
  )
}

# Function to attach core drwateR packages
drwateR_attach <- function() {
  to_load <- core_unloaded()
  if (length(to_load) > 0) {
    suppressPackageStartupMessages(
      invisible(lapply(to_load, same_library))
    )
  }
  invisible(to_load)
}

# Function to generate an attachment message for core drwateR packages
drwateR_attach_message <- function(to_load) {
  if (length(to_load) == 0) {
    return(NULL)
  }
  header <- cli::rule(
    left = cli::style_bold("Attaching core drwateR packages"),
    right = paste0("drwateR ", package_version_h("drwateR"))
  )
  to_load <- sort(to_load)
  versions <- vapply(to_load, package_version_h, character(1))
  packages <- paste0(
    cli::col_green(cli::symbol$tick), " ",
    cli::col_blue(format(to_load)), " ",
    cli::ansi_align(versions, max(cli::ansi_nchar(versions)))
  )
  if (length(packages) %% 2 == 1) {
    packages <- c(packages, "")
  }
  col1 <- seq_len(length(packages) / 2)
  info <- paste0(packages[col1], "     ", packages[-col1])
  paste0(header, "\n", paste(info, collapse = "\n"))
}

# Helper function to get the package version and highlight it
package_version_h <- function(pkg) {
  highlight_version(utils::packageVersion(pkg))
}

# Function to highlight the package version, especially if it's a development version
highlight_version <- function(x) {
  x <- as.character(x)
  is_dev <- function(x) {
    x <- suppressWarnings(as.numeric(x))
    !is.na(x) & x >= 9000
  }
  pieces <- strsplit(x, ".", fixed = TRUE)
  pieces <- lapply(pieces, function(x) ifelse(is_dev(x), cli::col_red(x), x))
  vapply(pieces, paste, collapse = ".", FUN.VALUE = character(1))
}
