#' Set the working directory to the script's location in RStudio
#'
#' This function sets the working directory to the directory of the currently
#' open script in RStudio. If not running in RStudio or the working directory
#' cannot be set, it returns `FALSE`.
#'
#' @param quiet Logical; if `FALSE`, a message is printed indicating whether
#' the working directory was successfully set. Default is `TRUE`.
#' @return Logical; `TRUE` if the working directory was successfully set,
#' `FALSE` otherwise.
#' @importFrom rstudioapi getSourceEditorContext
#' @export
#'
#' @examples
#' # Set the working directory to the script's location
#' set_wdrstudio()
set_wdrstudio <- function(..., quiet = TRUE) {
  wd <- try(dirname(rstudioapi::getSourceEditorContext()$path), silent = TRUE)
  if (length(grep("Error", wd)) == 0) {
    setwd(wd)
    if (!quiet) {
      message(sprintf("Working directory has been set to: %s", wd))
    }
    return(invisible(TRUE))
  } else {
    if (!quiet) {
      message("Failed to set the working directory.")
    }
    return(invisible(FALSE))
  }
}
