# drwateR

<!-- badges: start -->

[![Lifecycle: experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![CRAN status](https://www.r-pkg.org/badges/version/drwateR)](https://CRAN.R-project.org/package=drwateR)

<!-- badges: end -->

[drwateR](https://drwater.rcees.ac.cn/git/drwateR) is an R package primarily for internal use within the drwateR system. Installation requires access to the [DRAN](https://drwater.rcees.ac.cn/dran) repository. To obtain the necessary username and password, please contact the drwateR administrators.

## Installation Methods

### Method 1: Install from `dran` repository (recommended)

This method allows you to install the `drwateR` package directly from the DRAN repository.

```r
source("https://drwater.rcees.ac.cn/ftp/drwateR/install_drwateR.R")
# If you haven't configured your DRAN user access, you will be prompted for a username and password.
# Please contact drwateR support to request access.
# install for the first time
install_drwateR("drwateR", from = "git")
# once all dependencies are installed, when reinstall
install_drwateR("drwateR")
```

### Method 2: Install from GitHub

You can also install the development version of `drwateR` directly from GitHub.

```r
devtools::install_github("mingsu/drwateR")
```

## Install Other `drwateR` Packages

Once you have access to the DRAN repository, you can install other `drwateR` packages as follows:

### Using `install.packages`

#### Method 1: By setting up `dran` repo in `.Rprofile`

To set `dran` as a default repository in your R environment:

```r
drwateR::drwateR_repo()
install.packages("dwfun")
```

#### Method 2: Without setting `dran` as a default repo

If you prefer not to modify your `.Rprofile`, you can install packages directly from `dran`:

```r
install.packages("dwfun", repos = "https://drwater.rcees.ac.cn/dran")
```

### Using `install_drwateR`

Alternatively, you can use the `install_drwateR` function, which handles the installation process for you, whether from the `dran` repository or directly from a Git repository:

```r
# Install from `dran`
drwateR::install_drwateR("dwfun")

# Install from Git repository
drwateR::install_drwateR("dwfun", type = "git")
```

# `drwateR` 包使用说明

`drwateR` 是一个用于管理和安装来自 `drwater` 仓库和 Git 仓库中的 R 包的工具集。以下是该包中各个函数的详细使用方法。

## 1. 添加自定义仓库到 `.Rprofile`

**函数：** `drwater_repo`

**功能：** 将 `drwater` 仓库的设置添加到 `.Rprofile` 文件中，以便 R 在启动时自动使用该仓库。

**用法：**

```r
drwater_repo()
```

**参数：**

- `rprofilefn`：`.Rprofile` 文件的路径，默认为 `~/.Rprofile`。
- `repocode`：设置仓库的 R 代码，默认为 `options(repos = c(DRAN = "https://drwater.rcees.ac.cn/dran"))`。

## 2. 从 `drwater` Git 仓库下载包

**函数：** `download_drwateR`

**功能：** 从 `drwater` Git 仓库下载指定的包。

**用法：**

```r
download_drwateR(pkgname)
```

**参数：**

- `pkgname`：要下载的包名。
- `gitroot`：Git 仓库的根 URL，默认为 `drwater.rcees.ac.cn/git/`。
- `scheme`：URL 的协议，默认为 `"https"`。
- `cred`：Git 认证凭据，默认为 `credentials::git_credential_ask`。

**返回值：** 下载包的本地路径，如果下载失败则返回 `NULL`。

## 3. 从 `drwater` 仓库或 Git 仓库安装包

**函数：** `install_drwateR`

**功能：** 从 `drwater` 仓库或 Git 仓库安装指定的包，包括处理依赖关系。

**用法：**

```r
install_drwateR(pkgname)
```

**参数：**

- `pkgname`：要安装的包名。
- `dependency_reinstall`：是否重新安装依赖包，默认为 `FALSE`。
- `pkgpath`：本地包路径，默认为 `download_drwateR` 返回的路径。
- `drwaterpkgs`：`drwateR` 包的名称向量，默认为 `DRWATERPKGS`。
- `from`：包的来源，可以是 `"dran"` 或 `"git"`。
- `repos`：DRAN 仓库的 URL，默认为 `DRANREPOURL`。
- `force`：是否强制安装，即使包已经是最新版本，默认为 `FALSE`。

**返回值：** 安装是否成功的逻辑值，`TRUE` 表示成功，`FALSE` 表示失败。

## 4. 从 Git 仓库安装包

**函数：** `install_drwateR_git`

**功能：** 从指定的 Git 仓库安装 R 包，包括处理依赖关系和版本更新。

**用法：**

```r
install_drwateR_git(pkgname)
```

**参数：**

- `pkgname`：要安装的包名。
- `dependency_reinstall`：是否重新安装依赖包，默认为 `FALSE`。
- `pkgpath`：本地包路径，默认为 `download_drwateR` 返回的路径。
- `force`：是否强制安装，默认为 `FALSE`。

**返回值：** 安装是否成功的逻辑值，`TRUE` 表示成功，`FALSE` 表示失败。

## 5. 安装包的依赖关系

**函数：** `install_dependency`

**功能：** 安装包的依赖关系，包括来自 CRAN、GitHub 和 `drwateR` 的包。

**用法：**

```r
install_dependency(depdf)
```

**参数：**

- `depdf`：包含依赖包信息的数据框，必须包含 `pkgname`、`source` 和 `installed` 列。
- `dependency_reinstall`：是否重新安装所有依赖包，默认为 `FALSE`。

## 6. 查找包的所有依赖

**函数：** `dependency_drwateR`

**功能：** 查找本地 R 包源代码的所有依赖包，并根据来源进行分类。

**用法：**

```r
dependency_drwateR(pkgpath)
```

**参数：**

- `pkgpath`：本地包源代码的路径。
- `desc`：DESCRIPTION 文件内容的数据框，如果未提供，将从指定的 `pkgpath` 读取。
- `drwaterpkgs`：`drwateR` 包的名称向量，默认为 `DRWATERPKGS`。

**返回值：** 包含依赖包名称、是否已安装及其来源的数据框。

## 7. 更新 `drwateR` 包

**函数：** `update_drwateR`

**功能：** 从 `drwater` Git 仓库更新一个或多个 `drwateR` 包。

**用法：**

```r
update_drwateR()
```

**参数：**

- `pkgname`：要更新的包名向量，默认为 `DRWATERPKGS`。

**返回值：** 更新是否成功的逻辑值，`TRUE` 表示成功，`FALSE` 表示失败。

## 8. 从 `drwater` 仓库安装包

**函数：** `install_drwater_repo`

**功能：** 从 `drwater` 仓库安装指定的包，包括处理依赖关系。

**用法：**

```r
install_drwater_repo(pkgname)
```

**参数：**

- `pkgname`：要安装的包名。
- `dranrepo`：DRAN 仓库的 URL，默认为 `DRANREPOURL`。

**返回值：** 安装是否成功的逻辑值，`TRUE` 表示成功，`FALSE` 表示失败。
